@@ -37,33 +37,30 @@
 #include <iomanip>
 
 #include "CompilerDriver_procurve_acl.h"
+#include "AutomaticRules_iosacl.h"
 
 #include "PolicyCompiler_procurve_acl.h"
 #include "RoutingCompiler_procurve_acl.h"
 #include "OSConfigurator_procurve.h"
+#include "NamedObjectsAndGroupsSupport.h"
+#include "NamedObjectsManagerIOS.h"
 
-#include "fwbuilder/Resources.h"
-#include "fwbuilder/FWObjectDatabase.h"
-#include "fwbuilder/XMLTools.h"
-#include "fwbuilder/FWException.h"
-#include "fwbuilder/Firewall.h"
-#include "fwbuilder/Interface.h"
-#include "fwbuilder/Policy.h"
-#include "fwbuilder/NAT.h"
-#include "fwbuilder/Routing.h"
-
-#include "fwcompiler/Preprocessor.h"
-
-#include "fwbuilder/Resources.h"
-#include "fwbuilder/FWObjectDatabase.h"
-#include "fwbuilder/FWException.h"
 #include "fwbuilder/Cluster.h"
 #include "fwbuilder/ClusterGroup.h"
+#include "fwbuilder/FWException.h"
+#include "fwbuilder/FWObjectDatabase.h"
+#include "fwbuilder/FailoverClusterGroup.h"
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Interface.h"
+#include "fwbuilder/Library.h"
+#include "fwbuilder/NAT.h"
 #include "fwbuilder/Policy.h"
+#include "fwbuilder/Resources.h"
+#include "fwbuilder/Routing.h"
 #include "fwbuilder/StateSyncClusterGroup.h"
-#include "fwbuilder/FailoverClusterGroup.h"
+#include "fwbuilder/XMLTools.h"
+
+#include "fwcompiler/Preprocessor.h"
 
 #include <QStringList>
 #include <QFileInfo>
@@ -77,12 +74,14 @@ using namespace libfwbuilder;
 using namespace fwcompiler;
 
 
-QString CompilerDriver_procurve_acl::assembleManifest(Cluster *cluster, Firewall* fw, bool cluster_member)
+QString CompilerDriver_procurve_acl::assembleManifest(Cluster*, Firewall*, bool)
 {
     QString script_buffer;
     QTextStream script(&script_buffer, QIODevice::WriteOnly);
-    QString ofname = determineOutputFileName(cluster, fw, cluster_member, ".fw");
-    script << ";" << MANIFEST_MARKER << "* " << this->escapeFileName(ofname) << endl;
+
+    script << ";" << MANIFEST_MARKER
+           << "* " << this->escapeFileName(file_names[FW_FILE]) << endl;
+
     return script_buffer;
 }
 
@@ -107,7 +106,8 @@ QString CompilerDriver_procurve_acl::assembleFwScript(Cluster *cluster,
     options->setStr("prolog_script", options->getStr("procurve_acl_prolog_script"));
     options->setStr("epilog_script", options->getStr("procurve_acl_epilog_script"));
 
-    assembleFwScriptInternal(cluster, fw, cluster_member, oscnf, &script_skeleton, &top_comment, ";");
+    assembleFwScriptInternal(cluster, fw, cluster_member, oscnf,
+                             &script_skeleton, &top_comment, ";", true);
     return script_skeleton.expand();
 }
 
@@ -116,16 +116,14 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
                                          const std::string &single_rule_id)
 {
     Cluster *cluster = NULL;
-    if (!cluster_id.empty())
-        cluster = Cluster::cast(
-            objdb->findInIndex(objdb->getIntId(cluster_id)));
+    Firewall *fw = NULL;
 
-    Firewall *fw = Firewall::cast(
-        objdb->findInIndex(objdb->getIntId(firewall_id)));
-    assert(fw);
+    getFirewallAndClusterObjects(cluster_id, firewall_id, &cluster, &fw);
 
     try
     {
+        clearReadOnly(fw);
+
         // Copy rules from the cluster object
         populateClusterElements(cluster, fw);
 
@@ -135,7 +133,9 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
         // firewall fw This happens when we compile a member of a cluster
         current_firewall_name = fw->getName().c_str();
 
-        QString ofname = determineOutputFileName(cluster, fw, !cluster_id.empty(), ".fw");
+        determineOutputFileNames(cluster, fw, !cluster_id.empty(),
+                                 QStringList(""), QStringList("fw"),
+                                 QStringList(""));
 
         FWOptions* options = fw->getOptionsObject();
 
@@ -166,11 +166,29 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
 
         list<FWObject*> all_policies = fw->getByType(Policy::TYPENAME);
 
+        try
+        {
+            AutomaticRules_iosacl auto_rules(fw, persistent_objects);
+            auto_rules.addSshAccessRule();
+        } catch (FWException &ex)
+        {
+            abort(ex.toString());
+        }
+
+        // assign unique rule ids that later will be used to generate
+        // chain names.  This should be done after calls to
+        // findImportedRuleSets()
+        // NB: these ids are not used by this compiler
+
+        assignUniqueRuleIds(all_policies);
+
         vector<int> ipv4_6_runs;
 
         if (!single_rule_compile_on)
             system_configuration_script = safetyNetInstall(fw);
 
+        NamedObjectsManagerIOS named_objects_manager(persistent_objects, fw);
+
         // command line options -4 and -6 control address family for which
         // script will be generated. If "-4" is used, only ipv4 part will 
         // be generated. If "-6" is used, only ipv6 part will be generated.
@@ -189,6 +207,9 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
             if (ipv4_run) ipv4_6_runs.push_back(AF_INET);
         }
 
+        string clear_commands;
+        string object_groups_definitions;
+
         for (vector<int>::iterator i=ipv4_6_runs.begin(); 
              i!=ipv4_6_runs.end(); ++i)
         {
@@ -221,8 +242,10 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
 
                 PolicyCompiler_procurve_acl c(objdb, fw, ipv6_policy, oscnf.get());
 
+                c.setNamedObjectsManager(&named_objects_manager);
                 c.setSourceRuleSet( policy );
                 c.setRuleSetName(policy->getName());
+                c.setPersistentObjects(persistent_objects);
 
                 c.setSingleRuleCompileMode(single_rule_id);
                 if (inTestMode()) c.setTestMode();
@@ -256,6 +279,8 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
                         all_errors.push_back(c.getErrors("").c_str());
                     }
                     policy_script +=  c.getCompiledScript();
+                    clear_commands += c.printClearCommands();
+                    //named_objects_manager.saveObjectGroups();
 
                 } else
                     info(" Nothing to compile in Policy");
@@ -269,8 +294,10 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
                 // currently routing is supported only for ipv4
                 RoutingCompiler_procurve_acl r(objdb, fw, false, oscnf.get());
 
+                r.setNamedObjectsManager(&named_objects_manager);
                 r.setSourceRuleSet(routing);
                 r.setRuleSetName(routing->getName());
+                r.setPersistentObjects(persistent_objects);
 
                 r.setSingleRuleCompileMode(single_rule_id);
                 if (inTestMode()) r.setTestMode();
@@ -295,22 +322,42 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
             }
         }
 
+        /*
+         * compilers detach persistent objects when they finish, this
+         * means at this point library persistent_objects is not part
+         * of any object tree.
+         */
+        objdb->reparent(persistent_objects);
+
         if (haveErrorsAndWarnings())
         {
             all_errors.push_front(getErrors("").c_str());
         }
 
+        object_groups_definitions +=
+            named_objects_manager.getNamedObjectsDefinitions();
 
         if (single_rule_compile_on)
         {
             return formSingleRuleCompileOutput(
-                QString::fromUtf8((policy_script + routing_script).c_str()));
+                QString::fromUtf8(
+                    (object_groups_definitions +
+                     policy_script + routing_script).c_str()));
         }
 
+        if ( fw->getOptionsObject()->getBool("procurve_acl_acl_basic") ||
+             fw->getOptionsObject()->getBool("procurve_acl_acl_substitution"))
+        {
+            clear_commands += named_objects_manager.getClearCommands() + "\n";
+        }
+
+        system_configuration_script += clear_commands;
+        system_configuration_script += object_groups_definitions;
+
         QString script_buffer = assembleFwScript(
             cluster, fw, !cluster_id.empty(), oscnf.get());
 
-        ofname = getAbsOutputFileName(ofname);
+        QString ofname = getAbsOutputFileName(file_names[FW_FILE]);
 
         info("Output file name: " + ofname.toStdString());
         QFile fw_file(ofname);
@@ -329,12 +376,14 @@ QString CompilerDriver_procurve_acl::run(const std::string &cluster_id,
         } else
         {
             QString err(" Failed to open file %1 for writing: %2; Current dir: %3");
-            abort(err.arg(fw_file.fileName()).arg(fw_file.error()).arg(QDir::current().path()).toStdString());
+            abort(err.arg(fw_file.fileName())
+                  .arg(fw_file.error()).arg(QDir::current().path()).toStdString());
         }
     }
-    catch (FatalErrorInSingleRuleCompileMode &ex)
+    catch (FWException &ex)
     {
-        return QString::fromUtf8(getErrors("").c_str());
+        status = BaseCompiler::FWCOMPILER_ERROR;
+        return QString::fromUtf8(ex.toString().c_str());
     }
 
     return "";
