@@ -38,69 +38,62 @@
 #include <sstream>
 
 using namespace libfwbuilder;
+using namespace fwcompiler;
 using namespace std;
 
 const char *PIXObjectGroup::TYPENAME={"PIXObjectGroup"};
 
-string PIXObjectGroup::toString()  throw(FWException)
+
+QString PIXObjectGroup::groupMemberToString(FWObject *obj,
+                                           NamedObjectsManager*)
+    throw(libfwbuilder::FWException)
 {
     ostringstream ostr;
 
-    if (this->size()==0) return "";
-
-    ostr << getObjectGroupHeader();
-
-    for (FWObject::iterator i1=this->begin(); i1!=this->end(); ++i1)
+    if (this->getObjectGroupType() == NETWORK)
     {
-        FWObject *o   = *i1;
-        FWObject *obj = o;
-        if (FWReference::cast(o)!=NULL) obj=FWReference::cast(o)->getPointer();
-
-        switch (this->getObjectGroupType()) 
+        Address *a = Address::cast(obj);
+        assert(a!=NULL);
+        const InetAddr *addr = a->getAddressPtr();
+        ostr << "network-object ";
+        if (Network::cast(obj)!=NULL)
         {
-        case NETWORK:
-        {
-            Address *a = Address::cast(obj);
-            assert(a!=NULL);
-            const InetAddr *addr = a->getAddressPtr();
-            ostr << " network-object ";
-            if (Network::cast(obj)!=NULL)
-            {
-                const InetAddr *mask = a->getNetmaskPtr();
-                ostr << addr->toString() << " ";
-                ostr << mask->toString() << " ";
-            } else {
-                ostr << " host ";
-                ostr << addr->toString() << " ";
-            }
-            ostr << endl;
-            break;
+            const InetAddr *mask = a->getNetmaskPtr();
+            ostr << addr->toString() << " ";
+            ostr << mask->toString() << " ";
+        } else {
+            ostr << "host ";
+            ostr << addr->toString() << " ";
         }
-        case PROTO:
+        return ostr.str().c_str();
+
+    } else
+    {
+
+        if (IPService::isA(obj))
         {
-            ostr << " protocol-object ";
+            ostr << "protocol-object ";
             Service *s=Service::cast(obj);
             assert(s!=NULL);
             ostr << s->getProtocolName();
-            ostr << endl;
-            break;
+            return ostr.str().c_str();
         }
-        case ICMP_TYPE:
+
+        if (ICMPService::isA(obj))
         {
-            ostr << " icmp-object ";
+            ostr << "icmp-object ";
             ICMPService *s=ICMPService::cast(obj);
             assert(s!=NULL);
             if ( s->getInt("type")== -1)
                 ostr << "any";
             else
                 ostr << s->getInt("type");
-            ostr << endl;
-            break;
+            return ostr.str().c_str();
         }
-        case TCP_SERVICE:
-        case UDP_SERVICE:
+
+        if (TCPService::isA(obj) || UDPService::isA(obj))
         {
-            ostr << " port-object ";
+            ostr << "port-object ";
             Service *s=Service::cast(obj);
             assert(s!=NULL);
 
@@ -115,27 +108,34 @@ string PIXObjectGroup::toString()  throw(FWException)
                 else         ostr << "range " << rs << " " << re;
             }
             else ostr << "range 0 65535";
-            ostr << endl;
-            break;
-        }
-        default:
-            throw FWException("Unknown object group type");
+            return ostr.str().c_str();
         }
+
+        QString err("PIXObjectGroup: Unsupported object '%1' found in "
+                    "object group");
+        throw FWException(err.arg(obj->getName().c_str()).toStdString());
     }
-    ostr << " exit" << endl << endl;
-    return ostr.str();
+
+    return ostr.str().c_str();
 }
 
 string PIXObjectGroup::getObjectGroupClass()
 {
     switch (this->getObjectGroupType()) 
     {
-    case NETWORK:     return "network";
-    case PROTO:       return "protocol";
-    case ICMP_TYPE:   return "icmp-type";
-    case TCP_SERVICE: return "service";
-    case UDP_SERVICE: return "service";
-    default: throw FWException("Unknown object group type");
+    case NETWORK:         return "network";
+    case PROTO:           return "protocol";
+    case ICMP_TYPE:       return "icmp-type";
+    case TCP_SERVICE:     return "service";
+    case UDP_SERVICE:     return "service";
+    case TCP_UDP_SERVICE: return "service";
+    case MIXED_SERVICE:   return "service";;
+    default:
+    {
+        QString err("PIXObjectGroup::getObjectGroupClass(): Unknown object "
+                    "group type '%1'");
+        throw FWException(err.arg(this->getObjectGroupType()).toStdString());
+    }
     }
 }
 
@@ -145,11 +145,16 @@ string PIXObjectGroup::getObjectGroupHeader()
     ostr << "object-group " << getObjectGroupClass() << " " << this->getName();
     switch (this->getObjectGroupType()) 
     {
-    case TCP_SERVICE: ostr << " tcp"; break;
-    case UDP_SERVICE: ostr << " udp"; break;
+    case TCP_SERVICE:     ostr << " tcp"; break;
+    case UDP_SERVICE:     ostr << " udp"; break;
+    case TCP_UDP_SERVICE: ostr << " tcp-udp"; break;
     default: break;
     }
-    ostr << endl;
     return ostr.str();
 }
 
+string PIXObjectGroup::getObjectGroupFooter()
+{
+    return "exit";
+}
+
