@@ -26,19 +26,24 @@
 #include "config.h"
 
 #include "PolicyCompiler_cisco.h"
+#include "NamedObjectsManager.h"
+#include "NamedObjectsAndGroupsSupport.h"
+#include "NamedObjectsManager.h"
 
+#include "fwbuilder/AddressTable.h"
+#include "fwbuilder/Cluster.h"
 #include "fwbuilder/FWObjectDatabase.h"
-#include "fwbuilder/RuleElement.h"
-#include "fwbuilder/IPService.h"
 #include "fwbuilder/ICMPService.h"
-#include "fwbuilder/TCPService.h"
-#include "fwbuilder/UDPService.h"
+#include "fwbuilder/IPService.h"
+#include "fwbuilder/Interface.h"
+#include "fwbuilder/Library.h"
+#include "fwbuilder/Management.h"
 #include "fwbuilder/Network.h"
 #include "fwbuilder/Policy.h"
-#include "fwbuilder/Interface.h"
-#include "fwbuilder/Management.h"
 #include "fwbuilder/Resources.h"
-#include "fwbuilder/AddressTable.h"
+#include "fwbuilder/RuleElement.h"
+#include "fwbuilder/TCPService.h"
+#include "fwbuilder/UDPService.h"
 
 #include <iostream>
 #include <iomanip>
@@ -47,6 +52,9 @@
 #include <cstring>
 #include <assert.h>
 
+#include <QtDebug>
+
+
 using namespace libfwbuilder;
 using namespace fwcompiler;
 using namespace std;
@@ -59,8 +67,6 @@ PolicyCompiler_cisco::PolicyCompiler_cisco(FWObjectDatabase *_db,
                                            OSConfigurator *_oscnf) :
     PolicyCompiler(_db, fw, ipv6_policy, _oscnf) , helper(this)
 {
-    object_groups = new Group();
-    dbcopy->add( object_groups );
 }
 
 int PolicyCompiler_cisco::prolog()
@@ -127,50 +133,22 @@ string PolicyCompiler_cisco::debugPrintRule(Rule *r)
 {
     ostringstream str;
     PolicyRule *rule = PolicyRule::cast(r);
-    FWObject *rule_iface = dbcopy->findInIndex(rule->getInterfaceId());
-    string iname = (rule_iface!=NULL)?rule_iface->getName():"";
+
+//    FWObject *rule_iface = dbcopy->findInIndex(rule->getInterfaceId());
+//    string iname = (rule_iface!=NULL)?rule_iface->getName():"";
 
     string dir = rule->getDirectionAsString();
 
     str << PolicyCompiler::debugPrintRule(rule) <<
-        " " << dir << " " << iname << " " << rule->getStr("acl") <<
-        " intfId=" << rule->getInterfaceId() <<
-        " intfstr=" << rule->getInterfaceStr();
+        " " << dir 
+//        << " " << iname
+        << " " << rule->getStr("acl");
+//        " intfId=" << rule->getInterfaceId() <<
+//        " intfstr=" << rule->getInterfaceStr();
     return str.str();
 }
 
 
-void PolicyCompiler_cisco::addDefaultPolicyRule()
-{
-/*
- * set up backup ssh access to the firewall if told to do so
- */
-    if ( getCachedFwOpt()->getBool("mgmt_ssh") &&
-         !getCachedFwOpt()->getStr("mgmt_addr").empty() )
-    {
-        TCPService *ssh = dbcopy->createTCPService();
-        ssh->setDstRangeStart(22);
-        ssh->setDstRangeEnd(22);
-        dbcopy->add(ssh, false);
-
-        TCPService *ssh_rev = dbcopy->createTCPService();
-        ssh_rev->setSrcRangeStart(22);
-        ssh_rev->setSrcRangeEnd(22);
-        dbcopy->add(ssh_rev, false);
-
-        Network *mgmt_workstation = dbcopy->createNetwork();
-        mgmt_workstation->setAddressNetmask(
-            getCachedFwOpt()->getStr("mgmt_addr"));
-
-        dbcopy->add(mgmt_workstation, false);
-
-        PolicyCompiler::addMgmtRule(
-            mgmt_workstation, fw, ssh,
-            NULL, PolicyRule::Inbound, PolicyRule::Accept,
-            "backup ssh access rule");
-    }
-}
-
 bool PolicyCompiler_cisco::splitIfSrcAny::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
@@ -205,6 +183,11 @@ bool PolicyCompiler_cisco::splitIfSrcAny::processNext()
     return true;
 }
 
+/*
+ * This splits the rule if Dst==any and one or more icmp services are
+ * found in Srv. The name of this rule processor needs to be more
+ * descriptive.
+ */
 bool PolicyCompiler_cisco::splitIfDstAny::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
@@ -391,33 +374,30 @@ bool PolicyCompiler_cisco::NegationPhase1::processNext()
  */
 bool PolicyCompiler_cisco::splitIfRuleElementMatchesFW::processNext()
 {
-    PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    PolicyCompiler_cisco *cisco_comp=dynamic_cast<PolicyCompiler_cisco*>(compiler);
+    PolicyRule *rule = getNext(); if (rule==NULL) return false;
+    PolicyCompiler_cisco *cisco_comp = dynamic_cast<PolicyCompiler_cisco*>(compiler);
 
-    RuleElement    *re=RuleElement::cast(rule->getFirstByType(re_type));
-    int nre=re->size();
+    RuleElement *re = RuleElement::cast(rule->getFirstByType(re_type));
+    int nre = re->size();
 
     list<FWObject*> cl;
 
     for (list<FWObject*>::iterator i1=re->begin(); nre>1 && i1!=re->end(); ++i1)
     {
-	FWObject *o   = *i1;
-	FWObject *obj = NULL;
-	if (FWReference::cast(o)!=NULL) obj=FWReference::cast(o)->getPointer();
-        Address *a=Address::cast(obj);
+	FWObject *obj = FWReference::getObject(*i1);
+        Address *a = Address::cast(obj);
         assert(a!=NULL);
 
-//        InetAddr obj_addr=a->getAddress();
+        if (cisco_comp->complexMatch(a,cisco_comp->fw))
+        {
+	    cl.push_back(obj);
 
-        if (cisco_comp->complexMatch(a,cisco_comp->fw)) {
-
-	    cl.push_back(o);   // can not remove right now because remove invalidates iterator
             nre--;
 
-	    PolicyRule  *new_rule= compiler->dbcopy->createPolicyRule();
+	    PolicyRule  *new_rule = compiler->dbcopy->createPolicyRule();
 	    compiler->temp_ruleset->add(new_rule);
 	    new_rule->duplicate(rule);
-            RuleElement *new_re=RuleElement::cast(new_rule->getFirstByType(re_type));
+            RuleElement *new_re = RuleElement::cast(new_rule->getFirstByType(re_type));
 	    new_re->clearChildren();
 	    new_re->setAnyElement();
 	    new_re->addRef( a );
@@ -425,10 +405,11 @@ bool PolicyCompiler_cisco::splitIfRuleElementMatchesFW::processNext()
         }
         
     }
+
     if (!cl.empty())
     {
         for (list<FWObject*>::iterator i1=cl.begin(); i1!=cl.end(); ++i1)
-            re->remove( (*i1) );
+            re->removeRef(*i1);
     }
 
     tmp_queue.push_back(rule);
@@ -440,15 +421,16 @@ bool PolicyCompiler_cisco::specialCaseWithDynInterface::dropDynamicInterface(
     PolicyRule  *rule, PolicyRule::Direction cmp_dir, RuleElement *re)
 {
     PolicyRule::Direction dir=rule->getDirection();
-    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+//    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+
+    RuleElementItf *intf_re = rule->getItf();
+    FWObject *rule_iface = FWObjectReference::getObject(intf_re->front());
 
     list<FWObject*> cl;
     for (list<FWObject*>::iterator i1=re->begin(); i1!=re->end(); ++i1) 
     {
-        FWObject *o   = *i1;
-        FWObject *obj = o;
-        if (FWReference::cast(o)!=NULL) obj=FWReference::cast(o)->getPointer();
-        Interface  *ifs   =Interface::cast( obj );
+        FWObject *obj = FWObjectReference::getObject(*i1);
+        Interface  *ifs = Interface::cast( obj );
 
         if (ifs!=NULL && ifs->isDyn()) 
         {
@@ -512,54 +494,55 @@ bool PolicyCompiler_cisco::specialCaseWithDynInterface::processNext()
  */
 bool PolicyCompiler_cisco::tcpServiceToFW::processNext()
 {
-    PolicyRule     *rule=getNext(); if (rule==NULL) return false;
-    PolicyCompiler_cisco *cisco_comp=dynamic_cast<PolicyCompiler_cisco*>(compiler);
-//    RuleElementSrc *src=rule->getSrc();
-//    RuleElementDst *dst=rule->getDst();
-    RuleElementSrv *srv=rule->getSrv();
-    Address  *a=compiler->getFirstDst(rule);
+    PolicyRule *rule = getNext(); if (rule==NULL) return false;
+    PolicyCompiler_cisco *cisco_comp =
+        dynamic_cast<PolicyCompiler_cisco*>(compiler);
+
+    RuleElementSrv *srv = rule->getSrv();
+    Address *a = compiler->getFirstDst(rule);
     assert(a!=NULL);
 
-    if (rule->getAction()==PolicyRule::Accept && 
-        compiler->complexMatch(a,cisco_comp->fw)) 
+    if (rule->getAction()==PolicyRule::Accept
+        &&
+        (
+            (Cluster::cast(a) != NULL && Cluster::cast(a)->hasMember(compiler->fw))
+            ||
+            a->getId() == compiler->fw->getId()
+        )
+    )
     {
         std::list<FWObject*> cl;
         for (list<FWObject*>::iterator i1=srv->begin(); i1!=srv->end(); ++i1) 
         {
-            FWObject *o   = *i1;
-            FWObject *obj = NULL;
-            if (FWReference::cast(o)!=NULL) obj=FWReference::cast(o)->getPointer();
-            Service *s=Service::cast(obj);
+            FWObject *obj = FWReference::getObject(*i1);
+            Service *s = Service::cast(obj);
             assert(s!=NULL);
 
             if (TCPService::isA(s) && 
                 TCPUDPService::cast(s)->getDstRangeStart()==port && 
-                TCPUDPService::cast(s)->getDstRangeEnd()==port) cl.push_back(o);
+                TCPUDPService::cast(s)->getDstRangeEnd()==port) cl.push_back(obj);
         }
+
         if (!cl.empty()) 
         {
-
-            PolicyRule  *r= compiler->dbcopy->createPolicyRule();
+            PolicyRule  *r = compiler->dbcopy->createPolicyRule();
             compiler->temp_ruleset->add(r);
             r->duplicate(rule);
-            RuleElementDst *ndst=r->getDst();
+            RuleElementDst *ndst = r->getDst();
             ndst->clearChildren();
-            ndst->setAnyElement();
-
-            // Was commented out in r50
             ndst->addRef( compiler->fw );
 
-            RuleElementSrv *nsrv=r->getSrv();
+            RuleElementSrv *nsrv = r->getSrv();
             nsrv->clearChildren();
-            nsrv->add( cl.front() );
-            r->setBool("ssh_telnet_cmd",true);
+            nsrv->addRef( cl.front() );
+            r->setBool("tcp_service_to_fw", true);
             tmp_queue.push_back(r);
 
             for (list<FWObject*>::iterator i1=cl.begin(); i1!=cl.end(); ++i1)  
-                srv->remove( (*i1) );
+                srv->removeRef(*i1);
+
+            if ( ! srv->isAny()) tmp_queue.push_back(rule);
 
-            if (srv->size()>0)
-                tmp_queue.push_back(rule);
         } else
             tmp_queue.push_back(rule);
     } else
@@ -576,11 +559,14 @@ bool PolicyCompiler_cisco::tcpServiceToFW::processNext()
 bool PolicyCompiler_cisco::replaceFWinSRCInterfacePolicy::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+//    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+    RuleElementItf *intf_re = rule->getItf();
+    Interface *rule_iface = Interface::cast(
+        FWObjectReference::getObject(intf_re->front()));
 
-    if (rule_iface!=NULL && rule->getDirection()==PolicyRule::Outbound)
+    if ( rule_iface!=NULL && rule->getDirection()==PolicyRule::Outbound)
     {
-        RuleElementSrc *src=rule->getSrc();
+        RuleElementSrc *src = rule->getSrc();
         
         if (compiler->getFirstSrc(rule)->getId()==compiler->fw->getId()) 
         {
@@ -596,11 +582,14 @@ bool PolicyCompiler_cisco::replaceFWinSRCInterfacePolicy::processNext()
 bool PolicyCompiler_cisco::replaceFWinDSTInterfacePolicy::processNext()
 {
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+//    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+    RuleElementItf *intf_re = rule->getItf();
+    Interface *rule_iface = Interface::cast(
+        FWObjectReference::getObject(intf_re->front()));
 
-    if (rule_iface!=NULL && rule->getDirection()==PolicyRule::Inbound)
+    if ( rule_iface!=NULL && rule->getDirection()==PolicyRule::Inbound)
     {
-        RuleElementDst *dst=rule->getDst();
+        RuleElementDst *dst = rule->getDst();
 
         if (compiler->getFirstDst(rule)->getId()==compiler->fw->getId()) 
         {
@@ -621,12 +610,13 @@ bool PolicyCompiler_cisco::replaceFWinDSTPolicy::processNext()
 {
     Helper helper(compiler);
     PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+//    FWObject *rule_iface = compiler->dbcopy->findInIndex(rule->getInterfaceId());
+    RuleElementItf *intf_re = rule->getItf();
 
-    if (rule_iface==NULL)
+    if (intf_re->isAny())
     {
-        RuleElementSrc *src=rule->getSrc();
-        RuleElementDst *dst=rule->getDst();
+        RuleElementSrc *src = rule->getSrc();
+        RuleElementDst *dst = rule->getDst();
 
         if (!src->isAny() && compiler->getFirstDst(rule)->getId()==compiler->fw->getId()) 
         {
@@ -653,87 +643,6 @@ bool PolicyCompiler_cisco::replaceFWinDSTPolicy::processNext()
     return true;
 }
 
-void PolicyCompiler_cisco::splitByNetworkZonesForRE::AddToInterface(
-    int interface_id, Address *addr, PolicyRule *rule)
-{
-    PolicyRule  *new_rule;
-    RuleElement *new_re;
-
-    new_rule = rules[interface_id];
-    if (new_rule==NULL) 
-    {
-        new_rule = compiler->dbcopy->createPolicyRule();
-        compiler->temp_ruleset->add(new_rule);
-        new_rule->duplicate(rule);
-        rules[interface_id]=new_rule;
-        new_re=RuleElement::cast(new_rule->getFirstByType(re_type));
-        new_re->clearChildren();
-        new_re->setAnyElement();
-    }
-    new_re=RuleElement::cast(new_rule->getFirstByType(re_type));
-    new_re->addRef( addr );
-}
-
-bool PolicyCompiler_cisco::splitByNetworkZonesForRE::processNext()
-{
-    Helper helper(compiler);
-    PolicyRule *rule=getNext(); if (rule==NULL) return false;
-    RuleElement    *re=RuleElement::cast(rule->getFirstByType(re_type));
-    if (re->size()==1) 
-    {
-        tmp_queue.push_back(rule);
-        return true;
-    }
-    
-    rules.clear();
-
-    std::list<FWObject*> cl;
-    for (list<FWObject*>::iterator i1=re->begin(); i1!=re->end(); ++i1) 
-    {
-	FWObject *o   = *i1;
-	FWObject *obj = NULL;
-	if (FWReference::cast(o)!=NULL) obj=FWReference::cast(o)->getPointer();
-        Address *a=Address::cast(obj);
-        assert(a!=NULL);
-
-//        InetAddr obj_addr=a->getAddress();
-
-        try
-        {
-            int interface_id = helper.findInterfaceByNetzone(a);
-            AddToInterface(interface_id, a, rule);
-        } catch (string err)
-        {
-            // could not find interface with netzone to match address 'a'
-            // will assign rule to all interfaces. Act as if all interfaces
-            // had network zone 'any' and each matches this address.
-
-            // issue warning only if platform uses netwrk zones.
-
-            bool supports_network_zones =
-                Resources::getTargetCapabilityBool(
-                    compiler->fw->getStr("platform"), "network_zones");
-
-            if (supports_network_zones)
-                compiler->warning(rule, err);
-
-            FWObjectTypedChildIterator i =
-                compiler->fw->findByType(Interface::TYPENAME);
-            for ( ; i!=i.end(); ++i)
-            {
-                Interface  *ifs = Interface::cast(*i);
-                AddToInterface(ifs->getId(), a, rule);
-            }
-        }
-    }
-    for (std::map<int,PolicyRule*>::iterator i=rules.begin();
-         i!=rules.end(); ++i)
-    {
-        tmp_queue.push_back((*i).second);        
-    }
-    return true;
-}
-
 bool PolicyCompiler_cisco::equalObjCISCO::operator()(FWObject *o)
 {
     if (ICMPService::cast(obj)!=NULL && ICMPService::cast(o)!=NULL)
@@ -755,34 +664,38 @@ bool PolicyCompiler_cisco::removeRedundantAddresses::processNext()
         return true;
     }
 
-    std::map<Address*,FWObject*>  addrmap;
-    std::list<FWObject*> cl;
+    map<Address*, bool> status;
     for (list<FWObject*>::iterator i1=re->begin(); i1!=re->end(); ++i1) 
     {
         Address *a = Address::cast(FWReference::getObject(*i1));
         assert(a!=NULL);   // assuming all objects are addresses.
-        addrmap[a] = *i1;
+        status[a] = false;
     }
 
-    for (std::map<Address*,FWObject*>::iterator i1=addrmap.begin();
-         i1!=addrmap.end(); ++i1)
+    map<Address*,bool>::iterator i1;
+    map<Address*,bool>::iterator i2;
+    for (i1=status.begin(); i1!=status.end(); ++i1)
     {
         Address *a1 = i1->first;
-        const InetAddrMask* am1 = a1->getInetAddrMaskObjectPtr();
-        for (std::map<Address*,FWObject*>::iterator i2=addrmap.begin();
-             i2!=addrmap.end(); ++i2)
+        // const InetAddrMask* am1 = a1->getInetAddrMaskObjectPtr();
+
+        for (i2=status.begin(); i2!=status.end(); ++i2)
         {
+            if (i2->second) continue;
+
             Address *a2 = i2->first;
-            const InetAddrMask* am2 = a2->getInetAddrMaskObjectPtr();
-            if (am1 && am2 && am1->toString() == am2->toString()) continue;
-            if (compiler->checkForShadowing(*a1, *a2) ) cl.push_back(i1->second);
+            if (a1->getId() == a2->getId()) continue;
+
+            // const InetAddrMask* am2 = a2->getInetAddrMaskObjectPtr();
+            // if (am1 && am2 && am1->toString() == am2->toString()) continue;
+
+            if (compiler->checkForShadowing(*a1, *a2) ) status[a1] = true;
         }
     }
 
-    if (!cl.empty())
+    for (i1=status.begin(); i1!=status.end(); ++i1)
     {
-        for (list<FWObject*>::iterator i1=cl.begin(); i1!=cl.end(); ++i1)  
-            re->remove( (*i1) );
+        if (i1->second) re->removeRef(i1->first);
     }
 
     tmp_queue.push_back(rule);
@@ -812,7 +725,6 @@ bool PolicyCompiler_cisco::processMultiAddressObjectsInRE::processNext()
     return true;
 }
 
-
 void PolicyCompiler_cisco::compile()
 {
 }
@@ -883,3 +795,22 @@ void PolicyCompiler_cisco::epilog()
 {
 }
 
+string PolicyCompiler_cisco::printClearCommands()
+{
+    return "";
+}
+
+/*
+ * This includes commands that should be added first, such as commit mode
+ * for FWSM, setting up temporary access list etc.
+ */
+string PolicyCompiler_cisco::printPreambleCommands()
+{
+    return "";
+}
+
+void PolicyCompiler_cisco::setNamedObjectsManager(NamedObjectsManager *mgr)
+{
+    named_objects_manager = mgr;
+}
+
