@@ -34,6 +34,9 @@
 #include "Helper.h"
 #include "ACL.h"
 #include "BaseObjectGroup.h"
+#include "NamedObjectsAndGroupsSupport.h"
+#include "splitByNetworkZonesForRE.h"
+
 
 namespace libfwbuilder {
     class IPService;
@@ -52,15 +55,6 @@ namespace fwcompiler {
 
 protected:
 
-	/**
-	 * our firewall policy must block everything by default even
-	 * if there are no rules. In iptables we do this by setting
-	 * default chain policies to DROP. Here we do this by adding
-	 * this unconditional blocking rule in the end. See also comment
-	 * in the code regarding "pass_all_out" option
-	 */
-	virtual void addDefaultPolicyRule();
-
         /**
          * prints rule in some universal format (close to that visible
          * to user in the GUI). Used for debugging purposes. This method
@@ -297,7 +291,7 @@ protected:
         class telnetToFirewall : public tcpServiceToFW
         {
             public:
-            telnetToFirewall(const std::string &n):tcpServiceToFW(23,n) {}
+            telnetToFirewall(const std::string &n):tcpServiceToFW(23, n) {}
         };
         friend  class telnetToFirewall;
 
@@ -307,10 +301,20 @@ protected:
         class sshToFirewall : public tcpServiceToFW
         {
             public:
-            sshToFirewall(const std::string &n):tcpServiceToFW(22,n) {}
+            sshToFirewall(const std::string &n):tcpServiceToFW(22, n) {}
         };
         friend  class sshToFirewall;
 
+        /**
+         * this processor splits rules if it finds telnet to firewall
+         */
+        class httpToFirewall : public tcpServiceToFW
+        {
+            public:
+            httpToFirewall(const std::string &n):tcpServiceToFW(80, n) {}
+        };
+        friend  class httpToFirewall;
+
         /**
          * replace fw with one of its interfaces in SRC in interface
          * policy rule
@@ -330,24 +334,6 @@ protected:
         DECLARE_POLICY_RULE_PROCESSOR( replaceFWinDSTPolicy );
 
 
-        /**
-         * this processor splits rules if objects in rule element
-         * re_type belong to different network zones
-         */
-        class splitByNetworkZonesForRE : public PolicyRuleProcessor
-        {
-            std::string re_type;
-            std::map<int,libfwbuilder::PolicyRule*> rules;
-            void AddToInterface(int interface_id,
-                                libfwbuilder::Address *addr,
-                                libfwbuilder::PolicyRule *rule);
-            public:
-            splitByNetworkZonesForRE(const std::string &name,const std::string &_type) :
-                PolicyRuleProcessor(name) {re_type=_type; }
-            virtual bool processNext();
-        };
-
-
         class splitByNetworkZonesForSrc : public splitByNetworkZonesForRE
         {
             public:
@@ -447,7 +433,7 @@ protected:
                 processMultiAddressObjectsInRE(n,libfwbuilder::RuleElementDst::TYPENAME) {}
         };
 
-
+#ifdef OLD_STYLE_OBJECT_GROUP_SUPPORT
 	/**
 	 * this processor creates PIX-specific object groups
          * (PIX CLI command "object-group") for rules with
@@ -457,7 +443,7 @@ protected:
         {
             std::string re_type;
             std::string name_suffix;
-            BaseObjectGroup* findObjectGroup(libfwbuilder::RuleElement *re);
+
             public:
             CreateObjectGroups(const std::string &name,
                                const std::string &_ns,
@@ -503,20 +489,20 @@ protected:
         };
         friend class PolicyCompiler_cisco::printObjectGroups;
 
-
+#endif
+        
         
 protected:
 
         Helper helper;
-	std::map<std::string,ciscoACL*> acls;
-// storage for object groups created to be used with PIX command object-group
-        libfwbuilder::Group *object_groups;
+        NamedObjectsManager *named_objects_manager;
 
 	virtual std::string myPlatformName();
 
         std::string mangleInterfaceName(const std::string &interface_name);
 
 public:
+	std::map<std::string,ciscoACL*> acls;
 
 	PolicyCompiler_cisco(libfwbuilder::FWObjectDatabase *_db,
                              libfwbuilder::Firewall *fw,
@@ -532,12 +518,17 @@ public:
 	virtual void compile();
 	virtual void epilog();
 
+        virtual std::string printClearCommands();
+        virtual std::string printPreambleCommands();
+       
         /**
          * sort commands ('icmp', 'telnet', 'ssh') and access lists
          * in some kind of 'natural' order. Useful for both IOS and PIX
          */
         void regroup();
-	
+
+        void setNamedObjectsManager(NamedObjectsManager *mgr);
+
     };
 
 
