@@ -31,11 +31,12 @@
 
 #include "CompilerDriver.h"
 
-#include "fwbuilder/FWObjectDatabase.h"
-#include "fwbuilder/FWException.h"
 #include "fwbuilder/Cluster.h"
+#include "fwbuilder/FWException.h"
+#include "fwbuilder/FWObjectDatabase.h"
 #include "fwbuilder/Firewall.h"
 #include "fwbuilder/Interface.h"
+#include "fwbuilder/Library.h"
 #include "fwbuilder/Rule.h"
 
 #include "fwcompiler/Compiler.h"
@@ -92,7 +93,8 @@ void CompilerDriver::compile()
         for (list<Firewall*>::iterator it=members.begin(); it!=members.end(); ++it)
         {
             info("\n");
-            info(" Firewall " + (*it)->getName() + " member of cluster " + fw->getName());
+            info(" Firewall " + (*it)->getName() +
+                 " member of cluster " + fw->getName());
 
             CompilerDriver *cl_driver = clone();
             cl_driver->configure(args);
@@ -100,6 +102,8 @@ void CompilerDriver::compile()
             cl_driver->run(objdb->getStringId(fw->getId()),
                            objdb->getStringId((*it)->getId()),
                            "");
+            if (cl_driver->status == BaseCompiler::FWCOMPILER_ERROR)
+                status = cl_driver->status;
             delete cl_driver;
         }
     }
@@ -141,8 +145,15 @@ QMap<QString,QString> CompilerDriver::compileSingleRule(const string &rule_id)
     if (cluster)
     {
         commonChecks(cluster);
+
         list<Firewall*> members;
         Cluster::cast(cluster)->getMembersList(members);
+
+        // this copy of CompilerDriver is not going to do any useful work and
+        // does not need these.
+        objdb->remove(persistent_objects, false);
+        objdb->remove(workspace, false);
+
         for (list<Firewall*>::iterator it=members.begin(); it!=members.end(); ++it)
         {
             CompilerDriver *cl_driver = clone();
