@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@fwbuilder.org
 
-  $Id: linux24Interfaces.cpp 2907 2010-05-16 03:09:14Z vadim $
+  $Id$
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -57,29 +57,20 @@ bool linux24Interfaces::parseVlan(const QString &name, QString *base_name, int *
 }
 
 /*
- * Bridge interfaces on Linux can have "-" in the name
+ * per #1856, OpenWRT uses "-" in ppp interface names, such as
+ * "ppp-dsl". Also bridge interfaces can have "-" in their names. It
+ * seems we should just allow "-" in names instead of cherry-picking
  */
 bool linux24Interfaces::basicValidateInterfaceName(Interface *intf,
                                                    const QString &obj_name,
                                                    QString &err)
 {
-    string interface_type = intf->getOptionsObject()->getStr("type");
-
-    if (interface_type == "bridge")
+    if (obj_name.indexOf(' ') != -1)
     {
-        if (obj_name.indexOf(' ') != -1)
-        {
-            err = QObject::tr("Bridge interface name '%1' can not contain white space").arg(obj_name);
-            return false;
-        }
-        return true;
-    }
-
-    if (obj_name.indexOf(' ') != -1 || obj_name.indexOf('-') != -1)
-    {
-        err = QObject::tr("Interface name '%1' can not contain white space and \"-\"").arg(obj_name);
+        err = QObject::tr("Bridge interface name '%1' can not contain white space").arg(obj_name);
         return false;
     }
+    return true;
 
     return true;
 }
