@@ -26,10 +26,12 @@
 
 #include <assert.h>
 
-#include <fwbuilder/libfwbuilder-config.h>
+#include "config.h"
+#include "fwbuilder/libfwbuilder-config.h"
 
-#include <fwbuilder/ICMP6Service.h>
-#include <fwbuilder/XMLTools.h>
+
+#include "fwbuilder/ICMP6Service.h"
+#include "fwbuilder/XMLTools.h"
 
 using namespace libfwbuilder;
 using namespace std;
