@@ -26,7 +26,8 @@
 #ifndef __COMPILER_HH__
 #define __COMPILER_HH__
 
-#include <fwbuilder/libfwbuilder-config.h>
+#include "config.h"
+#include "fwbuilder/libfwbuilder-config.h"
 #include "fwbuilder/FWObjectDatabase.h"
 #include "fwbuilder/FWException.h"
 
