@@ -32,6 +32,7 @@
 
 #include "RoutingCompiler.h"
 
+#include "fwbuilder/AddressTable.h"
 #include "fwbuilder/AddressRange.h"
 #include "fwbuilder/RuleElement.h"
 #include "fwbuilder/Network.h"
@@ -53,6 +54,7 @@
 #include "fwbuilder/XMLTools.h"
 #include "fwbuilder/FWException.h"
 #include "fwbuilder/Group.h"
+#include "fwbuilder/MultiAddress.h"
 
 #include <iostream>
 #include <iomanip>
@@ -255,17 +257,21 @@ bool RoutingCompiler::singleAdressInRGtw::processNext()
 }
 
 // recursive network validity check
-bool RoutingCompiler::validateNetwork::checkValidNetwork(FWObject *o) {
-    
-    if( Network::cast(o) != NULL) {
+bool RoutingCompiler::validateNetwork::checkValidNetwork(FWObject *o)
+{
+    if( Network::cast(o) != NULL)
+    {
         return ((Network *)o)->isValidRoutingNet();
     }
-    
+
     /* if we have a group containing networks and groups, we want to check them too */
-    if( ObjectGroup::cast(o) != NULL) {
-        
-        FWObjectTypedChildIterator child_i = o->findByType(FWObjectReference::TYPENAME);
-        for ( ; child_i != child_i.end(); ++child_i) {
+    if( ObjectGroup::cast(o) != NULL)
+    {
+        FWObjectTypedChildIterator child_i =
+            o->findByType(FWObjectReference::TYPENAME);
+
+        for ( ; child_i != child_i.end(); ++child_i)
+        {
             FWObjectReference *child_r = FWObjectReference::cast(*child_i);
             assert(child_r);
             FWObject *child = child_r->getPointer();
@@ -274,12 +280,16 @@ bool RoutingCompiler::validateNetwork::checkValidNetwork(FWObject *o) {
             ObjectGroup *group;
             
             // Network
-            if ((network=Network::cast(child)) != NULL) {
-                if (checkValidNetwork(network) == false) {
+            if ((network=Network::cast(child)) != NULL)
+            {
+                if (checkValidNetwork(network) == false)
+                {
                     return false;
                 }
-            } else if ((group=ObjectGroup::cast(child)) != NULL) { // Group
-                if (checkValidNetwork(group) == false) {
+            } else if ((group=ObjectGroup::cast(child)) != NULL)
+            { // Group
+                if (checkValidNetwork(group) == false)
+                {
                     return false;
                 }
             }
@@ -299,8 +309,17 @@ bool RoutingCompiler::validateNetwork::processNext()
     RuleElementRDst *dstrel=rule->getRDst();
     FWObject *o = FWReference::cast(dstrel->front())->getPointer();
      
-    if( checkValidNetwork(o) == false) {
-    
+    // currently we do not support run-time DNSName and AddressTable objects
+    // in routing rules.
+    MultiAddress *ma = MultiAddress::cast(o);
+    if (ma && ma->isRunTime()) 
+    {
+        compiler->abort(rule, "Use of dynamic run-time objects "
+                        "as destination in routing rules is not supported.");
+    }
+
+    if( checkValidNetwork(o) == false)
+    {
         string msg;
         msg = "Object \"" + o->getName() +
             "\" used as destination in the routing rule " +
@@ -519,7 +538,8 @@ bool RoutingCompiler::rItfChildOfFw::processNext()
     Interface *iface = Interface::cast(o);
     if (iface)
     {
-        FWObject *parent = iface->getParentHost();
+        FWObject *parent = Host::getParentHost(iface);
+        //FWObject *parent = iface->getParentHost();
         if (parent->getId() == compiler->fw->getId()) return true;
 
         Cluster *cluster = Cluster::cast(parent);
@@ -830,4 +850,35 @@ bool RoutingCompiler::createSortedDstIdsLabel::processNext()
     return true;
 }
 
+/*
+ * This is identical to 
+ * PolicyCompiler_ipf::processMultiAddressObjectsInRE::processNext()
+ * TODO: move the code to the class Compiler so it can be reused.
+ */
+bool RoutingCompiler::processMultiAddressObjectsInRE::processNext()
+{
+    RoutingRule *rule = getNext(); if (rule==NULL) return false;
+    RuleElement *re = RuleElement::cast( rule->getFirstByType(re_type) );
+
+    for (FWObject::iterator i=re->begin(); i!=re->end(); i++)
+    {
+        FWObject *o= *i;
+        if (FWReference::cast(o)!=NULL) o=FWReference::cast(o)->getPointer();
+        MultiAddressRunTime *atrt = MultiAddressRunTime::cast(o);
+        if (atrt!=NULL && atrt->getSubstitutionTypeName()==AddressTable::TYPENAME)
+            compiler->abort(
+                rule, 
+                "Run-time AddressTable objects are not supported.");
+
+        AddressTable *at = AddressTable::cast(o);
+        if (at && at->isRunTime())
+            compiler->abort(
+                rule, 
+                "Run-time AddressTable objects are not supported.");
+    }
+
+    tmp_queue.push_back(rule);
+    return true;
+}
+
 
