@@ -27,7 +27,7 @@
 #ifndef __ADDRESSRANGEDIALOG_H_
 #define __ADDRESSRANGEDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_addressrangedialog_q.h>
 #include "BaseObjectDialog.h"
 #include <QWidget>
