@@ -24,7 +24,7 @@
 
 */
 
-#include "../../config.h"
+#include "config.h"
 #include "global.h"
 #include "utils.h"
 #include "events.h"
@@ -82,7 +82,6 @@
 #include "fwbuilder/Logger.h"
 
 #include "FWBSettings.h"
-#include "UserWorkflow.h"
 #include "ObjectManipulator.h"
 #include "FWWindow.h"
 #include "networkZoneManager.h"
@@ -852,8 +851,6 @@ void DiscoveryDruid::startConfigImport()
         thread->setTargetWidget(this);
         thread->start();
 
-        wfl->registerFlag(UserWorkflow::IMPORT, true);
-
     } else
     {
         QMessageBox::critical(this, tr("Discovery error"),
