@@ -35,12 +35,12 @@ FWBAboutDialog::FWBAboutDialog(QWidget *parent): QDialog(parent)
 {
     m_aboutDialog = new Ui::AboutDialog_q;
     m_aboutDialog->setupUi(this);
-    m_aboutDialog->titleLbl->setText(
-        QString("Firewall Builder v%1").arg(VERSION) );
-    m_aboutDialog->revLbl->setText(tr("Build: %1").arg(build_num));
-    m_aboutDialog->apiLbl->setText(
-        tr("Using Firewall Builder API %1").arg(
-            libfwbuilder::Constants::getLibraryVersion().c_str() ) );
+
+    QString pgm = m_aboutDialog->titleLbl->text();
+    m_aboutDialog->titleLbl->setText(pgm.arg(GENERATION));
+
+    m_aboutDialog->revLbl->setText(VERSION);
+    m_aboutDialog->apiLbl->setText("");
 
     ABOUT_DLG_BLANKS;
 
