@@ -152,6 +152,7 @@ public slots:
     
     void minimize();
     void maximize();
+
     virtual void search();
 
     virtual void restoreRuleSetTab();
@@ -201,8 +202,6 @@ public slots:
     virtual void install(std::set<libfwbuilder::Firewall * > vf);
     virtual void install();
     virtual void inspect();
-    virtual void transferfw(std::set<libfwbuilder::Firewall * > vf);
-    virtual void transferfw();
 
     virtual void insertRule();
     virtual void addRuleAfterCurrent();
@@ -216,7 +215,6 @@ public slots:
     virtual void pasteRuleAbove();
     virtual void pasteRuleBelow();
 
-    virtual void back();
     virtual void newObject();
     virtual void lockObject();
     virtual void unlockObject();
@@ -368,6 +366,9 @@ public slots:
                                  QPixmap *pm,
                                  bool include_file_name);
     void showIntroDialog();
+
+    void addNewObjectMenu(QMenu*);
+    void showNewObjectMenu();
     
  protected:
 
