@@ -23,7 +23,7 @@
 
 */
 
-#include "../../config.h"
+#include "config.h"
 #include "global.h"
 #include "utils.h"
 #include "utils_no_qt.h"
@@ -35,7 +35,6 @@
 #include "FirewallInstaller.h"
 #include "SSHSession.h"
 #include "SSHUnx.h"
-#include "UserWorkflow.h"
 #include "instDialog.h"
 
 #include "fwbuilder/Resources.h"
@@ -536,8 +535,6 @@ void FirewallInstaller::runJobs()
     instJob current_job = job_list.front();
     job_list.pop_front();
 
-    wfl->registerFlag(UserWorkflow::INSTALL_RAN, true);
-
     switch (current_job.job) 
     {
     case COPY_FILE:
