@@ -27,7 +27,7 @@
 #ifndef __ICMPSERVICEDIALOG_H_
 #define __ICMPSERVICEDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_icmpservicedialog_q.h>
 #include "BaseObjectDialog.h"
 #include <QWidget>
