@@ -27,7 +27,7 @@
 #ifndef __NETWORKDIALOG_H_
 #define __NETWORKDIALOG_H_
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_networkdialog_q.h>
 #include "BaseObjectDialog.h"
 #include <QWidget>
