@@ -211,17 +211,6 @@ public:
     
     bool saveIfModified(bool include_discard_button=true);
 
-    // semi-intelligent way to guess most appropriate
-    // destination directory for various file save or file open
-    // operations. If working directory is configured in
-    // preferences, then getDestDir returns that. If it is not
-    // configured and file name is given on the command line,
-    // directory where that file is located is returned. If
-    // parameter filename is empty, then current directory
-    // is returned (however on windows and mac userDataDir is returned)
-
-    QString getDestDir(const QString &filename);
-    
     QString chooseNewFileName(const QString &fname, const QString &title);
     void setFileName(const QString &fname);
     void restoreDepends(libfwbuilder::FWObject *obj_old,
@@ -234,15 +223,10 @@ public:
     void setActive();
 
  private:
-    void adjustDockWidths(bool makeZeroWidth);
-    
+
  public slots:
     void newObject();
-
-    void topLevelChangedForTreePanel(bool topLevel);
-    void visibilityChangedForTreePanel(bool topLevel);
     
-    virtual void back();
     virtual void lockObject();
     virtual void unlockObject();
  
@@ -281,8 +265,6 @@ public:
     virtual void install(std::set<libfwbuilder::Firewall*> vf);
     virtual void install();
     virtual void inspect(std::set<libfwbuilder::Firewall*> vf);
-    virtual void transferfw(std::set<libfwbuilder::Firewall*> vf);
-    virtual void transferfw();
 
     void splitterMoved ( int pos, int index );
 
@@ -299,10 +281,6 @@ public:
 
     void aboutToActivate();
     
-#if QT_VERSION < 0x040500
-    void setTreeDockPosition();
-#endif
-
     void splitterPositionChanged(int, int);
 
 public:
@@ -346,7 +324,7 @@ public:
     QString printHeader();
 
     void toggleViewTree(bool f);
-
+    
 protected:
     int oldState ;
     virtual void showEvent(QShowEvent *ev);
