@@ -24,8 +24,8 @@
 */
 
 
-#include "../../config.h"
-#include "../../definitions.h"
+#include "config.h"
+#include "definitions.h"
 #include "global.h"
 #include "utils.h"
 #include "platforms.h"
