@@ -31,7 +31,7 @@
 #include <qstringlist.h>
 #include <QDialog>
 
-#include "../../config.h"
+#include "config.h"
 #include <ui_filepropdialog_q.h>
 
 class RCS;
