@@ -6,7 +6,7 @@
 
   Author:  Vadim Kurland     vadim@vk.crocodile.org
 
-  $Id: PolicyCompiler_ipf.h 1594 2009-10-13 22:11:42Z vadim $
+  $Id$
 
   This program is free software which we release under the GNU General Public
   License. You may redistribute and/or modify this program under the terms
@@ -236,7 +236,7 @@ namespace fwcompiler {
             virtual void _printWith(libfwbuilder::Service *srv);
             virtual void _printAction(libfwbuilder::PolicyRule *r);
             virtual void _printAddr(libfwbuilder::Address  *o,bool neg=false);
-            virtual void _printDstService(libfwbuilder::RuleElementSrv  *o);
+            virtual void _printDstService(libfwbuilder::RuleElement  *o);
 
             public:
             PrintRule(const std::string &name);
