@@ -53,6 +53,7 @@
 #include "fwbuilder/XMLTools.h"
 #include "fwbuilder/FWException.h"
 #include "fwbuilder/Tools.h"
+#include "fwbuilder/Constants.h"
 
 #include <QApplication>
 #include <QStringList>
@@ -84,7 +85,7 @@ void usage(const char *name)
 {
     cout << "Firewall Builder:  policy compiler for Cisco PIX firewall (with support for FWSM)" << endl;
     cout << "Copyright 2002-2009 NetCitadel, LLC" << endl;
-    cout << "Version " << VERSION << "-" << build_num.toStdString() << endl;
+    cout << "Version " << VERSION << endl;
     cout << "Usage: " << name << " [-tvV] [-f filename.xml] [-d destdir] [-o output.fw] firewall_object_name" << endl;
 }
 
@@ -118,12 +119,6 @@ int main(int argc, char **argv)
             only_print_inspection_code = true;
             continue;
         }
-        if (arg == "-r")
-        {
-            idx++;
-            respath = string(args.at(idx).toLatin1().constData());
-            continue;
-        }
         if (arg == "-V")
         {
             usage(argv[0]);
@@ -147,7 +142,7 @@ int main(int argc, char **argv)
 
     try
     {
-        new Resources(respath + FS_SEPARATOR + "resources.xml");
+        new Resources(Constants::getResourcesFilePath());
 
 /* create database */
         objdb = new FWObjectDatabase();
@@ -158,7 +153,7 @@ int main(int argc, char **argv)
         cout << " *** Loading data ...";
 
         objdb->setReadOnly( false );
-        objdb->load( filename, &upgrade_predicate, librespath);
+        objdb->load( filename, &upgrade_predicate, Constants::getDTDDirectory());
         objdb->setFileName(filename);
         objdb->reIndex();
 
@@ -167,33 +162,32 @@ int main(int argc, char **argv)
         FWObject *slib = objdb->getById(FWObjectDatabase::STANDARD_LIB_ID);
         if (slib && slib->isReadOnly()) slib->setReadOnly(false);
 
-        CompilerDriver_pix driver(objdb);
-        if (!driver.prepare(args))
+        CompilerDriver_pix *driver = new CompilerDriver_pix(objdb);
+        if (!driver->prepare(args))
         {
             usage(argv[0]);
             exit(1);
         }
         if (only_print_inspection_code)
         {
-            cout << driver.protocolInspectorCommands();
+            cout << driver->protocolInspectorCommands();
         } else
-            driver.compile();
+            driver->compile();
+        int ret = (driver->getStatus() == BaseCompiler::FWCOMPILER_SUCCESS) ? 0 : 1;
 
+        delete driver;
         delete objdb;
-        return 0;
 
-    } catch(libfwbuilder::FWException &ex)  {
+        return ret;
+
+    } catch(libfwbuilder::FWException &ex)
+    {
         cerr << ex.toString() << endl;
         return 1;
-    } catch (std::string s) {
+    } catch (std::string s)
+    {
         cerr << s << endl;
         return 1;
-//     } catch (std::exception ex) {
-//         cerr << "exception: " << ex.what() << endl;
-//         return 1;
-//     } catch (...) {
-//         cerr << "Unsupported exception";
-//         return 1;
     }
 
     return 0;
