@@ -53,6 +53,7 @@
 #include "fwbuilder/XMLTools.h"
 #include "fwbuilder/FWException.h"
 #include "fwbuilder/Tools.h"
+#include "fwbuilder/Constants.h"
 
 #include <QApplication>
 #include <QStringList>
@@ -82,7 +83,7 @@ void usage(const char *name)
 {
     cout << "Firewall Builder:  policy compiler for HP ProCurve ACL" << endl;
     cout << "Copyright 2010 NetCitadel, LLC" << endl;
-    cout << "Version " << VERSION << "-" << build_num.toStdString() << endl;
+    cout << "Version " << VERSION << endl;
     cout << "Usage: " << name << " [-tvV] [-f filename.xml] [-d destdir] [-o output.fw] firewall_object_name" << endl;
 }
 
@@ -109,12 +110,6 @@ int main(int argc, char **argv)
     {
         QString arg = args.at(idx);
         last_arg = arg;
-        if (arg == "-r")
-        {
-            idx++;
-            respath = string(args.at(idx).toLatin1().constData());
-            continue;
-        }
         if (arg == "-V")
         {
             usage(argv[0]);
@@ -138,7 +133,7 @@ int main(int argc, char **argv)
 
     try
     {
-        new Resources(respath+FS_SEPARATOR+"resources.xml");
+        new Resources(Constants::getResourcesFilePath());
  
         /* create database */
         objdb = new FWObjectDatabase();
@@ -149,7 +144,7 @@ int main(int argc, char **argv)
         cout << " *** Loading data ...";
 
         objdb->setReadOnly( false );
-        objdb->load( filename, &upgrade_predicate, librespath);
+        objdb->load( filename, &upgrade_predicate, Constants::getDTDDirectory());
         objdb->setFileName(filename);
         objdb->reIndex();
 
@@ -158,16 +153,20 @@ int main(int argc, char **argv)
         FWObject *slib = objdb->getById(FWObjectDatabase::STANDARD_LIB_ID);
         if (slib && slib->isReadOnly()) slib->setReadOnly(false);
 
-        CompilerDriver_procurve_acl driver(objdb);
-        if (!driver.prepare(args))
+        CompilerDriver_procurve_acl *driver = new CompilerDriver_procurve_acl(objdb);
+        if (!driver->prepare(args))
         {
             usage(argv[0]);
             exit(1);
         }
 
-        driver.compile();
+        driver->compile();
+        int ret = (driver->getStatus() == BaseCompiler::FWCOMPILER_SUCCESS) ? 0 : 1;
+
+        delete driver;
         delete objdb;
-        return 0;
+
+        return ret;
         
     } catch(libfwbuilder::FWException &ex)
     {
