@@ -73,7 +73,6 @@
 #include "RoutingRuleOptionsDialog.h"
 #include "platforms.h"
 #include "NATRuleOptionsDialog.h"
-#include "UserWorkflow.h"
 
 using namespace std;
 using namespace libfwbuilder;
@@ -82,7 +81,6 @@ void genericDialogTest::initTestCase()
 {
     new FWObjectClipboard();
     mw = new FWWindow();
-    wfl = new UserWorkflow();
     mw->show();
     mw->startupLoad();
     mw->resize(1200, 600);
